==> node-utopian-rocks-0.0.1.tgz: package/test/response_type.test.js <==
const utopian = require('../src/api');

// Retrieve moderators
test('return an object for all moderators', async () => {
  expect(typeof await utopian.getModerators()).toBe('object');
});

// Retrieve posts by category and status
test('return an object for all pending posts in development category', async () => {
  expect(typeof await utopian.getPosts('development', 'pending')).toBe('object');
});

// Retrieve posts by category,status,staff_picked
test('return an object for all pending posts in development category that has been picked by staff', async () => {
  expect(typeof await utopian.getPosts('development', 'pending', null, null, true)).toBe('object');
});

// Retrieve all pending posts
test('returns an object for all pending posts', async () => {
  expect(typeof await utopian.getPosts('pending')).toBe('object');
});

// Retrieve all reviewed posts
test('returns an object for all reviewed posts', async () => {
  expect(typeof await utopian.getPosts('reviewed')).toBe('object');
});

// Retrieve unreviewed posts
test('returns an object for all unreviewed posts', async () => {
  expect(typeof await utopian.getPosts('unreviewed')).toBe('object');
});

// Retrieve unvoted posts
test('returns an object for all unvoted posts', async () => {
  expect(typeof await utopian.getPosts('unvoted')).toBe('object');
});

// Retrieve all projects statistics
test('returns an object for all projects statistics', async () => {
  expect(typeof await utopian.getStats('projects')).toBe('object');
});

// Retrieve staff picks statistics
test('returns an object for all staff picks statistics', async () => {
  expect(typeof await utopian.getStats('staff_picks')).toBe('object');
});

// Retrieve moderators statistics
test('returns an object for all moderators statistics', async () => {
  expect(typeof await utopian.getStats('moderators')).toBe('object');
});

// Retrieve all statistics
test('returns an object for all statistics sections', async () => {
  expect(typeof await utopian.getStats()).toBe('object');
});

==> node-utopian-rocks-0.0.3.tgz: package/test/response_type.test.js <==
const utopian = require('../src/api');

// Retrieve moderators
test('returns an object for all moderators', async () => {
  expect(typeof await utopian.getModerators()).toBe('object');
});

// Retrieve posts by category and status
test('returns an object for all pending posts in development category', async () => {
  expect(typeof await utopian.getPosts('development', 'pending')).toBe('object');
});

// Retrieve posts by category,status,staff_picked
test('returns an object for all pending posts in development category that has been picked by staff', async () => {
  expect(typeof await utopian.getPosts('development', 'pending', null, null, true)).toBe('object');
});

// Retrieve all pending posts
test('returns an object for all pending posts', async () => {
  expect(typeof await utopian.getPosts('pending')).toBe('object');
});

// Retrieve all reviewed posts
test('returns an object for all reviewed posts', async () => {
  expect(typeof await utopian.getPosts('reviewed')).toBe('object');
});

// Retrieve unreviewed posts
test('returns an object for all unreviewed posts', async () => {
  expect(typeof await utopian.getPosts('unreviewed')).toBe('object');
});

// Retrieve unvoted posts
test('returns an object for all unvoted posts', async () => {
  expect(typeof await utopian.getPosts('unvoted')).toBe('object');
});

// Retrieve all projects statistics
test('returns an object for all projects statistics', async () => {
  expect(typeof await utopian.getStats('projects')).toBe('object');
});

// Retrieve staff picks statistics
test('returns an object for all staff picks statistics', async () => {
  expect(typeof await utopian.getStats('staff_picks')).toBe('object');
});

// Retrieve moderators statistics
test('returns an object for all moderators statistics', async () => {
  expect(typeof await utopian.getStats('moderators')).toBe('object');
});

// Retrieve all statistics
test('returns an object for all statistics sections', async () => {
  expect(typeof await utopian.getStats()).toBe('object');
});
